# Models - Library - Linen

Flax Linen-based neural network models for quantum device characterization.

::: inspeqtor.models.library.linen

::: inspeqtor.models.library.linen.WoModel

::: inspeqtor.models.library.linen.UnitaryModel

::: inspeqtor.models.library.linen.UnitarySPAMModel

::: inspeqtor.models.library.linen.train_model

::: inspeqtor.models.library.linen.make_predictive_fn

::: inspeqtor.models.library.linen.create_step

::: inspeqtor.models.library.linen.make_loss_fn
